import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_media/DataBase.dart';

class Game {
  final String title;
  final String url;
  final String dev;
  final String editor;
  final String plateformes;
  final String genres;
  final String score;
  final String releaseDate;
  final String description;
  bool isSaved=false;

  Game(this.title, this.url, this.dev, this.editor, this.plateformes, this.genres, this.score, this.releaseDate,  this.description );
}

class DetailGameScreen extends StatefulWidget {
  final Game game;

  // In the constructor, require a manga
  DetailGameScreen({Key key, @required this.game}) : super(key: key);

  @override
  _DetailGameScreenState createState() => _DetailGameScreenState();
}

class _DetailGameScreenState extends State<DetailGameScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Détails de l'oeuvre"),
      ),
      body: Padding(
        padding: EdgeInsets.all(4.0),
        child: ListView(
          padding: const EdgeInsets.all(8),
          children: <Widget>[
            Container(
                height: 25,
                child:  RichText(text: TextSpan(children: <TextSpan>[
                  TextSpan(text: "Titre: ", style: boldTitleStyle,),
                  TextSpan(text: "${widget.game.title}", style: classicTitleStyle,),
                ],),)
            ),
            Container(
              height: 225,
              child: GridView.count(
                  childAspectRatio: 0.8,
                  crossAxisCount: 2,
                  physics: new NeverScrollableScrollPhysics(),
                  children: <Widget>[
                    Image.network(widget.game.url),
                    Align(alignment: Alignment.center, child: RichText(text: TextSpan(children: <TextSpan>[
                      TextSpan(text: "Développeurs: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.dev}\n", style: classicStyle,),
                      TextSpan(text: "Éditeurs: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.editor}\n", style: classicStyle,),
                      TextSpan(text: "Genres: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.genres}\n", style: classicStyle,),
                      TextSpan(text: "Plateformes: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.plateformes}\n", style: classicStyle,),
                      TextSpan(text: "Date de sortie: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.releaseDate}\n", style: classicStyle,),
                      TextSpan(text: "Note communautaire: ", style: boldStyle,),
                      TextSpan(text: "${widget.game.score}\n", style: classicStyle,),
                    ],),))
                  ]),
            ),
            Container(
                height: 400,
                child:RichText(textAlign: TextAlign.justify,text: TextSpan(children: <TextSpan>[
                  TextSpan(text: "En bref:\n", style: boldTitleStyle,),
                  TextSpan(text: "${widget.game.description}\n", style: classicStyle,),
                ],),)
            )],
        ),
      ),

      floatingActionButtonLocation: FloatingActionButtonLocation.endFloat,
      floatingActionButton: new FloatingActionButton(
        onPressed:(){
          setState(() {
            if (widget.game.isSaved) {
              widget.game.isSaved=false;
            } else {
              widget.game.isSaved=true;
            }
          });
        },
        tooltip: 'Fav',
        child: new Icon( widget.game.isSaved ? Icons.favorite : Icons.favorite_border,
          color: widget.game.isSaved ? Colors.red : null,),
      ),
    );
  }
}

Widget getGameList(DataBase dataBase){
  const TextStyle titleStyle2 = TextStyle(fontSize: 44, fontWeight: FontWeight.bold, color:  Colors.blue);
  return ListView.separated(
    physics: ScrollPhysics(),
    padding: const EdgeInsets.all(0),
    itemCount: dataBase.getGameViews().length+1,
    itemBuilder: (BuildContext context, int index) {
      if(index==0) return Container(
        height: 60,
        child: Text('Mes jeux-vidéos',style: titleStyle2,textAlign: TextAlign.center),
      );
      else return Container(
        height: 180,
        child: InkWell( onTap: () {Navigator.push(context, MaterialPageRoute(builder: (context) => DetailGameScreen(game: DataBase.games[index-1])),);
        },
          child: Center(child: dataBase.getGameViews()[index-1]),),
      );
    },
    separatorBuilder: (BuildContext context, int index) => const Divider(thickness: 5 ,color: Colors.blue, indent: 10, endIndent: 10,),
  );
}